NAME
API::Docker::Type::ContainerBlkioStats - BlkioStats stores all IO service stats for data read and write
VERSION
version 0.004
DESCRIPTION
Generated from the ContainerBlkioStats definition of spec/v1.51.yaml.
This type is Linux-specific and holds many fields that are specific to cgroups v1. On a cgroup v2 host, all fields other than io_service_bytes_recursive are omitted or null.
This type is only populated on Linux and omitted for Windows containers.
io_service_bytes_recursive
Undocumented upstream. Bytes transferred, one entry per device and operation. It is the only one of the eight arrays a cgroup v2 host fills in, which is also why it is the only one carrying no description: the other seven each say they are cgroup v1 only, and this one had nothing left to qualify. See API::Docker::Type::ContainerBlkioStatEntry. Serialised as io_service_bytes_recursive -- spelled out, because deriving it from the Perl name would produce IoServiceBytesRecursive.
io_serviced_recursive
This field is only available when using Linux containers with cgroups v1. It is omitted or null when using cgroups v2. See API::Docker::Type::ContainerBlkioStatEntry. Serialised as io_serviced_recursive -- spelled out, because deriving it from the Perl name would produce IoServicedRecursive.
io_queue_recursive
This field is only available when using Linux containers with cgroups v1. It is omitted or null when using cgroups v2. See API::Docker::Type::ContainerBlkioStatEntry. Serialised as io_queue_recursive -- spelled out, because deriving it from the Perl name would produce IoQueueRecursive.
io_service_time_recursive
This field is only available when using Linux containers with cgroups v1. It is omitted or null when using cgroups v2. See API::Docker::Type::ContainerBlkioStatEntry. Serialised as io_service_time_recursive -- spelled out, because deriving it from the Perl name would produce IoServiceTimeRecursive.
io_wait_time_recursive
This field is only available when using Linux containers with cgroups v1. It is omitted or null when using cgroups v2. See API::Docker::Type::ContainerBlkioStatEntry. Serialised as io_wait_time_recursive -- spelled out, because deriving it from the Perl name would produce IoWaitTimeRecursive.
io_merged_recursive
This field is only available when using Linux containers with cgroups v1. It is omitted or null when using cgroups v2. See API::Docker::Type::ContainerBlkioStatEntry. Serialised as io_merged_recursive -- spelled out, because deriving it from the Perl name would produce IoMergedRecursive.
io_time_recursive
This field is only available when using Linux containers with cgroups v1. It is omitted or null when using cgroups v2. See API::Docker::Type::ContainerBlkioStatEntry. Serialised as io_time_recursive -- spelled out, because deriving it from the Perl name would produce IoTimeRecursive.
sectors_recursive
This field is only available when using Linux containers with cgroups v1. It is omitted or null when using cgroups v2. See API::Docker::Type::ContainerBlkioStatEntry. Serialised as sectors_recursive -- spelled out, because deriving it from the Perl name would produce SectorsRecursive.
SUPPORT
Issues
Please report bugs and feature requests on GitHub at https://github.com/Getty/p5-api-docker/issues.
CONTRIBUTING
Contributions are welcome! Please fork the repository and submit a pull request.
AUTHOR
Torsten Raudssus <getty@cpan.org>
COPYRIGHT AND LICENSE
This software is copyright (c) 2026 by Torsten Raudssus <torsten@raudssus.de> https://raudssus.de/.
This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.