NAME

API::Docker::Type::ContainerStatsResponse - Statistics sample for a container

VERSION

version 0.004

DESCRIPTION

Generated from the ContainerStatsResponse definition of spec/v1.51.yaml.

name

Name of the container. Serialised as name -- spelled out, because deriving it from the Perl name would produce Name.

id

ID of the container. Serialised as id -- spelled out, because deriving it from the Perl name would produce Id.

read

Date and time at which this sample was collected. The value is formatted as RFC 3339 with nano-seconds. Serialised as read -- spelled out, because deriving it from the Perl name would produce Read.

preread

Date and time at which this first sample was collected. This field is not propagated if the "one-shot" option is set. If the "one-shot" option is set, this field may be omitted, empty, or set to a default date (0001-01-01T00:00:00Z).

The value is formatted as RFC 3339 with nano-seconds. Serialised as preread -- spelled out, because deriving it from the Perl name would produce Preread.

pids_stats

PidsStats contains Linux-specific stats of a container's process-IDs (PIDs). See API::Docker::Type::ContainerPidsStats. Serialised as pids_stats -- spelled out, because deriving it from the Perl name would produce PidsStats.

blkio_stats

BlkioStats stores all IO service stats for data read and write. See API::Docker::Type::ContainerBlkioStats. Serialised as blkio_stats -- spelled out, because deriving it from the Perl name would produce BlkioStats.

num_procs

The number of processors on the system.

This field is Windows-specific and always zero for Linux containers. Serialised as num_procs -- spelled out, because deriving it from the Perl name would produce NumProcs.

storage_stats

StorageStats is the disk I/O stats for read/write on Windows. See API::Docker::Type::ContainerStorageStats. Serialised as storage_stats -- spelled out, because deriving it from the Perl name would produce StorageStats.

cpu_stats

CPU related info of the container. See API::Docker::Type::ContainerCPUStats. Serialised as cpu_stats -- spelled out, because deriving it from the Perl name would produce CpuStats.

precpu_stats

CPU related info of the container. See API::Docker::Type::ContainerCPUStats. Serialised as precpu_stats -- spelled out, because deriving it from the Perl name would produce PrecpuStats.

memory_stats

Aggregates all memory stats since container inception on Linux. See API::Docker::Type::ContainerMemoryStats. Serialised as memory_stats -- spelled out, because deriving it from the Perl name would produce MemoryStats.

networks

Network statistics for the container per interface.

This field is omitted if the container has no networking enabled. See API::Docker::Type::ContainerNetworkStats. The keys are the caller's data and are never translated. Serialised as networks -- spelled out, because deriving it from the Perl name would produce Networks.

SUPPORT

Issues

Please report bugs and feature requests on GitHub at https://github.com/Getty/p5-api-docker/issues.

CONTRIBUTING

Contributions are welcome! Please fork the repository and submit a pull request.

AUTHOR

Torsten Raudssus <getty@cpan.org>

COPYRIGHT AND LICENSE

This software is copyright (c) 2026 by Torsten Raudssus <torsten@raudssus.de> https://raudssus.de/.

This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.