NAME
API::Docker::Type::NetworkAttachmentConfig - Specifies how a service should be attached to a particular network
VERSION
version 0.004
DESCRIPTION
Generated from the NetworkAttachmentConfig definition of spec/v1.51.yaml.
target
The target network for attachment. Must be a network name or ID.
aliases
Discoverable alternate names for the service on this network.
driver_opts
Driver attachment options for the network target. The keys are the caller's data and are never translated.
SUPPORT
Issues
Please report bugs and feature requests on GitHub at https://github.com/Getty/p5-api-docker/issues.
CONTRIBUTING
Contributions are welcome! Please fork the repository and submit a pull request.
AUTHOR
Torsten Raudssus <getty@cpan.org>
COPYRIGHT AND LICENSE
This software is copyright (c) 2026 by Torsten Raudssus <torsten@raudssus.de> https://raudssus.de/.
This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.