NAME
API::Docker::Type::NodeSpec - The body of a POST /nodes/{id}/update request
VERSION
version 0.004
DESCRIPTION
Generated from the NodeSpec definition of spec/v1.51.yaml, which the swagger leaves undescribed. paths: says what it is: the body of a POST /nodes/{id}/update request.
name
Name for the node.
labels
User-defined key/value metadata. The keys are the caller's data and are never translated.
role
Role of the node. The swagger enumerates worker and manager.
availability
Availability of the node. The swagger enumerates active, pause and drain.
SUPPORT
Issues
Please report bugs and feature requests on GitHub at https://github.com/Getty/p5-api-docker/issues.
CONTRIBUTING
Contributions are welcome! Please fork the repository and submit a pull request.
AUTHOR
Torsten Raudssus <getty@cpan.org>
COPYRIGHT AND LICENSE
This software is copyright (c) 2026 by Torsten Raudssus <torsten@raudssus.de> https://raudssus.de/.
This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.