NAME

API::Docker::Type::PluginPrivilege - Describes a permission the user has to accept upon installing the plugin

VERSION

version 0.004

DESCRIPTION

Generated from the PluginPrivilege definition of spec/v1.51.yaml.

name

Undocumented upstream. What the permission is over, network in the swagger's example.

description

Undocumented upstream.

value

Undocumented upstream. What is being asked for, one string each: ["host"] beside that network in the swagger's example.

SUPPORT

Issues

Please report bugs and feature requests on GitHub at https://github.com/Getty/p5-api-docker/issues.

CONTRIBUTING

Contributions are welcome! Please fork the repository and submit a pull request.

AUTHOR

Torsten Raudssus <getty@cpan.org>

COPYRIGHT AND LICENSE

This software is copyright (c) 2026 by Torsten Raudssus <torsten@raudssus.de> https://raudssus.de/.

This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.