NAME
API::Docker::Type::ServiceSpec - User modifiable configuration for a service
VERSION
version 0.004
DESCRIPTION
Generated from the ServiceSpec definition of spec/v1.51.yaml.
name
Name of the service.
labels
User-defined key/value metadata. The keys are the caller's data and are never translated.
task_template
User modifiable task configuration. See API::Docker::Type::TaskSpec.
mode
Scheduling mode for the service. See API::Docker::Type::ServiceSpec::Mode.
update_config
Specification for the update strategy of the service. See API::Docker::Type::ServiceSpec::UpdateConfig.
rollback_config
Specification for the rollback strategy of the service. See API::Docker::Type::ServiceSpec::RollbackConfig.
networks
Specifies which networks the service should attach to.
Deprecated: This field is deprecated since v1.44. The Networks field in TaskSpec should be used instead. See API::Docker::Type::NetworkAttachmentConfig.
endpoint_spec
Properties that can be configured to access and load balance a service. See API::Docker::Type::EndpointSpec.
SUPPORT
Issues
Please report bugs and feature requests on GitHub at https://github.com/Getty/p5-api-docker/issues.
CONTRIBUTING
Contributions are welcome! Please fork the repository and submit a pull request.
AUTHOR
Torsten Raudssus <getty@cpan.org>
COPYRIGHT AND LICENSE
This software is copyright (c) 2026 by Torsten Raudssus <torsten@raudssus.de> https://raudssus.de/.
This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.