NAME

API::Docker::Type::SwarmSpec::Orchestration - Orchestration configuration

VERSION

version 0.004

DESCRIPTION

Generated from the inline Orchestration schema of the SwarmSpec definition in spec/v1.51.yaml.

task_history_retention_limit

The number of historic tasks to keep per instance or node. If negative, never remove completed or failed tasks.

SUPPORT

Issues

Please report bugs and feature requests on GitHub at https://github.com/Getty/p5-api-docker/issues.

CONTRIBUTING

Contributions are welcome! Please fork the repository and submit a pull request.

AUTHOR

Torsten Raudssus <getty@cpan.org>

COPYRIGHT AND LICENSE

This software is copyright (c) 2026 by Torsten Raudssus <torsten@raudssus.de> https://raudssus.de/.

This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.