NAME
API::Docker::Type::SwarmSpec::Raft - Raft configuration
VERSION
version 0.004
DESCRIPTION
Generated from the inline Raft schema of the SwarmSpec definition in spec/v1.51.yaml.
snapshot_interval
The number of log entries between snapshots.
keep_old_snapshots
The number of snapshots to keep beyond the current snapshot.
log_entries_for_slow_followers
The number of log entries to keep around to sync up slow followers after a snapshot is created.
election_tick
The number of ticks that a follower will wait for a message from the leader before becoming a candidate and starting an election. ElectionTick must be greater than HeartbeatTick.
A tick currently defaults to one second, so these translate directly to seconds currently, but this is NOT guaranteed.
heartbeat_tick
The number of ticks between heartbeats. Every HeartbeatTick ticks, the leader will send a heartbeat to the followers.
A tick currently defaults to one second, so these translate directly to seconds currently, but this is NOT guaranteed.
SUPPORT
Issues
Please report bugs and feature requests on GitHub at https://github.com/Getty/p5-api-docker/issues.
CONTRIBUTING
Contributions are welcome! Please fork the repository and submit a pull request.
AUTHOR
Torsten Raudssus <getty@cpan.org>
COPYRIGHT AND LICENSE
This software is copyright (c) 2026 by Torsten Raudssus <torsten@raudssus.de> https://raudssus.de/.
This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.