NAME

API::Docker::Type::TaskSpec::ContainerSpec::Privileges::Seccomp - Options for configuring seccomp on the container

VERSION

version 0.004

DESCRIPTION

Generated from the inline Seccomp schema of TaskSpec.ContainerSpec.Privileges in spec/v1.51.yaml.

mode

Undocumented upstream. Which of the three the container gets. custom is the one that gives "profile" a job -- the swagger describes that field as the custom seccomp profile, as a JSON object. The swagger enumerates default, unconfined and custom.

profile

The custom seccomp profile as a json object.

SUPPORT

Issues

Please report bugs and feature requests on GitHub at https://github.com/Getty/p5-api-docker/issues.

CONTRIBUTING

Contributions are welcome! Please fork the repository and submit a pull request.

AUTHOR

Torsten Raudssus <getty@cpan.org>

COPYRIGHT AND LICENSE

This software is copyright (c) 2026 by Torsten Raudssus <torsten@raudssus.de> https://raudssus.de/.

This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.