NAME

API::Docker::Type::TaskSpec::NetworkAttachmentSpec - Read-only spec type for non-swarm containers attached to swarm overlay networks

VERSION

version 0.004

DESCRIPTION

Generated from the inline NetworkAttachmentSpec schema of the TaskSpec definition in spec/v1.51.yaml.

> Note: ContainerSpec, NetworkAttachmentSpec, and PluginSpec are > mutually exclusive. PluginSpec is only used when the Runtime field > is set to plugin. NetworkAttachmentSpec is used when the Runtime > field is set to attachment.

container_id

ID of the container represented by this task. Serialised as ContainerID -- spelled out, because deriving it from the Perl name would produce ContainerId.

SUPPORT

Issues

Please report bugs and feature requests on GitHub at https://github.com/Getty/p5-api-docker/issues.

CONTRIBUTING

Contributions are welcome! Please fork the repository and submit a pull request.

AUTHOR

Torsten Raudssus <getty@cpan.org>

COPYRIGHT AND LICENSE

This software is copyright (c) 2026 by Torsten Raudssus <torsten@raudssus.de> https://raudssus.de/.

This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.