NAME
API::Docker::Type::FilesystemChange - Change in the container's filesystem
VERSION
version 0.004
DESCRIPTION
Generated from the FilesystemChange definition of spec/v1.51.yaml.
path
Path to file or directory that has changed. The swagger lists this field as required; nothing here enforces that, see "since is documentation" in API::Docker::Type.
kind
Kind of change
Can be one of:
0: Modified ("C")1: Added ("A")2: Deleted ("D")
The swagger lists this field as required; nothing here enforces that, see "since is documentation" in API::Docker::Type.
SUPPORT
Issues
Please report bugs and feature requests on GitHub at https://github.com/Getty/p5-api-docker/issues.
CONTRIBUTING
Contributions are welcome! Please fork the repository and submit a pull request.
AUTHOR
Torsten Raudssus <getty@cpan.org>
COPYRIGHT AND LICENSE
This software is copyright (c) 2026 by Torsten Raudssus <torsten@raudssus.de> https://raudssus.de/.
This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.